@@ -28,7 +28,7 @@ NULL
 }
 
 .onAttach = function(libname, pkgname) {
-  if (getOMLConfig()$apikey == "PLEASE CHANGE ME")
+  if (getOMLConfig()$apikey == "")
     packageStartupMessage(paste0("Please use the 'setOMLConfig' or 'saveOMLConfig' function to set the API key.\n",
       "You can generate the API key from your OpenML account at http://www.openml.org/u#!api"))
 }
